@@ -1,6 +1,4 @@
 /*
- * "$Id: paper.h,v 1.2 2008/01/15 03:48:45 rlk Exp $"
- *
  *   libgimpprint paper functions.
  *
  *   Copyright 1997-2000 Michael Sweet (mike@easysw.com) and
@@ -64,7 +62,9 @@ typedef enum
   /** Standard paper size */
   PAPERSIZE_TYPE_STANDARD = 0,
   /** Envelope */
-  PAPERSIZE_TYPE_ENVELOPE
+  PAPERSIZE_TYPE_ENVELOPE,
+  /** Special (not normally displayed) */
+  PAPERSIZE_TYPE_SPECIAL
 } stp_papersize_type_t;
 
 /** The papersize data type. */
@@ -103,31 +103,47 @@ extern int stp_known_papersizes(void);
 /**
  * Get a papersize by name.
  * @param name the short unique name of the paper.
- * @returns a pointer to the papersize, or NULL on failure.  The
- * pointer should not be freed.
+ * @returns a static pointer to the papersize, or NULL on failure.
  */
 extern const stp_papersize_t *stp_get_papersize_by_name(const char *name);
 
 /**
  * Get a papersize by size.
  * The nearest available size to the size requested will be found.
+ * Only paper sizes within 5 points of width and height will be considered.
  * @param length the length of the paper.
  * @param width the width of the paper
- * @returns a pointer to the papersize, or NULL on failure.  The
- * pointer should not be freed.
+ * @returns a static pointer to the papersize, or NULL on failure.
  */
 extern const stp_papersize_t *stp_get_papersize_by_size(int length,
 							int width);
 
+/**
+ * Get a papersize by size if an exact match is found.
+ * @param length the length of the paper.
+ * @param width the width of the paper
+ * @returns a static pointer to the papersize, or NULL on failure.
+ */
+extern const stp_papersize_t *stp_get_papersize_by_size_exact(int length,
+							      int width);
+
 /**
  * Get a papersize by its index number.
  * @param idx the index number.  This must not be greater than (total
  * number of papers - 1).
- * @returns a pointer to the papersize, or NULL on failure.  The
- * pointer should not be freed.
+ * @returns a static pointer to the papersize, or NULL on failure.
  */
 extern const stp_papersize_t *stp_get_papersize_by_index(int idx);
 
+/**
+ * Get the default paper dimensions for the current configuration.
+ * The default is derived from the PageSize parameter if set, otherwise
+ * the default page size for the printer is used.  If no value can be
+ * determined, 1x1 will be returned.
+ * @param v the Gutenprint vars object
+ * @param width pointer to storage that the width will be returned in.
+ * @param height pointer to storage that the height will be returned in.
+ */
 extern void stp_default_media_size(const stp_vars_t *v,
 				   int *width, int *height);
 
@@ -138,6 +154,3 @@ extern void stp_default_media_size(const stp_vars_t *v,
 #endif
 
 #endif /* GUTENPRINT_PAPER_H */
-/*
- * End of "$Id: paper.h,v 1.2 2008/01/15 03:48:45 rlk Exp $".
- */
