@@ -91,7 +91,7 @@ struct kodak605_media_list {
 struct kodak605_status {
 	struct kodak605_sts_hdr hdr;
 /*@10*/	uint32_t ctr_life;  /* Lifetime Prints */
-	uint32_t ctr_maint; /* Prints since last maintainence */
+	uint32_t ctr_maint; /* Prints since last maintenance */
 	uint32_t ctr_media; /* Prints on current media */
 	uint32_t ctr_cut;   /* Cutter Actuations */
 	uint32_t ctr_head;  /* Prints on current head */
@@ -164,7 +164,7 @@ static const char *kodak68xx_mediatypes(int type)
 
 #define CMDBUF_LEN 4
 
-/* Private data stucture */
+/* Private data structure */
 struct kodak605_ctx {
 	struct libusb_device_handle *dev;
 	uint8_t endp_up;
@@ -291,7 +291,7 @@ static int kodak605_read_parse(void *vctx, int data_fd) {
 	if (ret < 0 || ret != sizeof(ctx->hdr)) {
 		if (ret == 0)
 			return CUPS_BACKEND_CANCEL;
-		ERROR("Read failed (%d/%d/%d)\n", 
+		ERROR("Read failed (%d/%d/%d)\n",
 		      ret, 0, (int)sizeof(ctx->hdr));
 		perror("ERROR: Read failed");
 		return CUPS_BACKEND_CANCEL;
@@ -683,7 +683,7 @@ struct dyesub_backend kodak605_backend = {
 	.teardown = kodak605_teardown,
 	.read_parse = kodak605_read_parse,
 	.main_loop = kodak605_main_loop,
-	.devices = { 
+	.devices = {
 	{ USB_VID_KODAK, USB_PID_KODAK_605, P_KODAK_605, "Kodak"},
 	{ 0, 0, 0, ""}
 	}
