@@ -1,5 +1,4 @@
 /*
- * "$Id: escputil.c,v 1.104 2010/12/11 22:04:07 rlk Exp $"
  *
  *   Printer maintenance utility for EPSON Stylus (R) printers
  *
@@ -27,11 +26,13 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
+#include <strings.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <signal.h>
 #include <sys/wait.h>
 #include <ctype.h>
+#include <time.h>
 #if defined(HAVE_VARARGS_H) && !defined(HAVE_STDARG_H)
 #include <varargs.h>
 #else
@@ -61,11 +62,14 @@ void do_head_clean(void);
 void do_help(int code);
 void do_identify(void);
 void do_ink_level(void);
-void do_extended_ink_info(int);
+void do_extended_ink_info(void);
 void do_nozzle_check(void);
 void do_status(void);
+void do_reset_ink_levels(void);
 int do_print_cmd(void);
 
+#pragma GCC diagnostic ignored "-Woverlength-strings"
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
 
 const char *banner = N_("\
 Escputil version " VERSION ", Copyright (C) 2000-2006 Robert Krawitz\n\
@@ -103,6 +107,7 @@ struct option optlist[] =
   { "nozzle-check",		0,	NULL,	(int) 'n' },
   { "align-head",		0,	NULL,	(int) 'a' },
   { "status",           	0,      NULL,   (int) 's' },
+  { "reset-ink-levels",        	0,      NULL,   (int) 'X' },
   { "new",			0,	NULL,	(int) 'u' },
   { "help",			0,	NULL,	(int) 'h' },
   { "identify",			0,	NULL,	(int) 'd' },
@@ -117,7 +122,7 @@ struct option optlist[] =
 };
 
 const char *help_msg = N_("\
-Usage: escputil [-c | -n | -a | -i | -e | -s | -d | -l | -M]\n\
+Usage: escputil [-c | -n | -a | -i | -e | -s | -d | -l | -M | -X]\n\
                 [-P printer | -r device] [-u] [-q] [-m model] [ -S ]\n\
                 [-C choices] [-p patterns]\n\
 Perform maintenance on EPSON Stylus (R) printers.\n\
@@ -142,6 +147,9 @@ Examples: escputil --ink-level --raw-device /dev/usb/lp0\n\
     -d|--identify      Query the printer for make and model information.\n\
                        This requires read/write access to the raw printer\n\
                        device.\n\
+    -X|--reset-ink     Reset ink levels.\n\
+                       This requires read/write access to the raw printer\n\
+                       device.\n\
     -l|--license       Display the license/warranty terms of this program.\n\
     -M|--list-models   List the available printer models.\n\
     -h|--help          Print this help message.\n\
@@ -161,7 +169,7 @@ Examples: escputil --ink-level --raw-device /dev/usb/lp0\n\
 #else
 const char *help_msg = N_("\
 Usage: escputil [OPTIONS] [COMMAND]\n\
-Usage: escputil [-c | -n | -a | -i | -e | -s | -d | -l | -M]\n\
+Usage: escputil [-c | -n | -a | -i | -e | -s | -d | -l | -M | -X]\n\
                 [-P printer | -r device] [-u] [-q] [-m model] [ -S ]\n\
                 [-C choices] [-p patterns]\n\
 Perform maintenance on EPSON Stylus (R) printers.\n\
@@ -185,6 +193,8 @@ Examples: escputil -i -r /dev/usb/lp0\n\
           read/write access to the raw printer device.\n\
     -d Query the printer for make and model information.  This\n\
           requires read/write access to the raw printer device.\n\
+    -X Reset ink levels. This requires read/write access to the raw\n\
+          printer device.\n\
     -l Display the license/warranty terms of this program.\n\
     -M List the available printer models.\n\
     -h Print this help message.\n\
@@ -264,7 +274,7 @@ exit_packet_mode_old(int do_init)
 {
   static char hdr[] = "\000\000\000\033\001@EJL 1284.4\n@EJL     \n\033@";
   memcpy(printer_cmd + bufpos, hdr, sizeof(hdr) - 1); /* DON'T include null! */
-  STP_DEBUG(printf("Exit packet mode (%d)\n", do_init));
+  STP_DEBUG(printf("***Exit packet mode (%d)\n", do_init));
   bufpos += sizeof(hdr) - 1;
   if (!do_init)
     bufpos -= 2;
@@ -274,7 +284,7 @@ static void
 initialize_print_cmd(int do_init)
 {
   bufpos = 0;
-  STP_DEBUG(printf("Initialize print command\n"));
+  STP_DEBUG(printf("***Initialize print command\n"));
   if (isnew)
     exit_packet_mode_old(do_init);
 }
@@ -283,7 +293,7 @@ static void
 initialize_print_cmd_new(int do_init)
 {
   bufpos = 0;
-  STP_DEBUG(printf("Initialize print command (force new)\n"));
+  STP_DEBUG(printf("***Initialize print command (force new)\n"));
   exit_packet_mode_old(do_init);
 }
 
@@ -296,7 +306,7 @@ main(int argc, char **argv)
 
   /* Set up gettext */
 #ifdef HAVE_LOCALE_H
-  char *locale = stp_strdup(setlocale (LC_ALL, ""));
+  (void) setlocale (LC_ALL, "");
 #endif
 #ifdef ENABLE_NLS
   bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
@@ -312,9 +322,9 @@ main(int argc, char **argv)
     {
 #if defined(HAVE_GETOPT_H) && defined(HAVE_GETOPT_LONG)
       int option_index = 0;
-      c = getopt_long(argc, argv, "P:r:iecnasduqm:hlMSC:p:", optlist, &option_index);
+      c = getopt_long(argc, argv, "P:r:iecnasXduqm:hlMSC:p:", optlist, &option_index);
 #else
-      c = getopt(argc, argv, "P:r:iecnasduqm:hlMSC:p:");
+      c = getopt(argc, argv, "P:r:iecnasXduqm:hlMSC:p:");
 #endif
       if (c == -1)
 	break;
@@ -331,6 +341,7 @@ main(int argc, char **argv)
 	case 'd':
 	case 's':
 	case 'o':
+	case 'X':
 	  if (operation)
 	    do_help(1);
 	  operation = c;
@@ -421,7 +432,7 @@ main(int argc, char **argv)
       do_ink_level();
       break;
     case 'e':
-      do_extended_ink_info(1);
+      do_extended_ink_info();
       break;
     case 'a':
       do_align();
@@ -432,6 +443,9 @@ main(int argc, char **argv)
     case 's':
       do_status();
       break;
+    case 'X':
+      do_reset_ink_levels();
+      break;
     default:
       do_help(1);
     }
@@ -445,7 +459,7 @@ print_debug_data(const char *buf, size_t count)
   for (i = 0; i < count; i++)
     {
       if (i % 16 == 0)
-	printf("\n%4d: ", i);
+	printf("\n***%4d: ", i);
       else if (i % 4 == 0)
 	printf(" ");
       if (isgraph(buf[i]))
@@ -498,7 +512,7 @@ do_print_cmd(void)
 	  return 1;
 	}
     }
-  STP_DEBUG(printf("Sending print command to %s:",
+  STP_DEBUG(printf("***Sending print command to %s:",
 		    raw_device ? raw_device : command));
   STP_DEBUG(print_debug_data(printer_cmd, bufpos));
   while (bytes < bufpos)
@@ -565,7 +579,8 @@ read_from_printer(int fd, char *buf, int bufsize, int quiet)
       status = read(fd, buf, bufsize - 1);
       if (status == 0 || (status < 0 && errno == EAGAIN))
 	{
-	  usleep(2000);
+	  struct timespec tm = {0, 2000000};
+	  nanosleep(&tm, &tm);
 	  status = 0; /* not an error (read would have blocked) */
 	}
     }
@@ -573,7 +588,7 @@ read_from_printer(int fd, char *buf, int bufsize, int quiet)
 
   if (status > 0)
     {
-      STP_DEBUG(printf("read_from_printer returns %d\n", status));
+      STP_DEBUG(printf("***read_from_printer returns %d\n", status));
       STP_DEBUG(print_debug_data(buf, status));
     }
   else if (status == 0 && retry == 0)
@@ -596,16 +611,16 @@ start_remote_sequence(void)
   static char remote_hdr[] = "\033@\033(R\010\000\000REMOTE1";
   memcpy(printer_cmd + bufpos, remote_hdr, sizeof(remote_hdr) - 1);
   bufpos += sizeof(remote_hdr) - 1;
-  STP_DEBUG(printf("Start remote sequence\n"));
+  STP_DEBUG(printf("***Start remote sequence\n"));
 }
 
 static void
 end_remote_sequence(void)
-{  
+{
   static char remote_trailer[] = "\033\000\000\000\033\000";
   memcpy(printer_cmd + bufpos, remote_trailer, sizeof(remote_trailer) - 1);
   bufpos += sizeof(remote_trailer) - 1;
-  STP_DEBUG(printf("End remote sequence\n"));
+  STP_DEBUG(printf("***End remote sequence\n"));
 }
 
 static void
@@ -617,7 +632,7 @@ do_remote_cmd(const char *cmd, int nargs, ...)
 
   start_remote_sequence();
   memcpy(printer_cmd + bufpos, cmd, 2);
-  STP_DEBUG(printf("Remote command: %s", cmd));
+  STP_DEBUG(printf("***Remote command: %s", cmd));
   bufpos += 2;
   printer_cmd[bufpos] = nargs % 256;
   printer_cmd[bufpos + 1] = (nargs >> 8) % 256;
@@ -634,6 +649,7 @@ do_remote_cmd(const char *cmd, int nargs, ...)
   STP_DEBUG(printf("\n"));
   bufpos += 2 + nargs;
   end_remote_sequence();
+  va_end(args);
 }
 
 static void
@@ -644,7 +660,7 @@ do_remote_cmd_only(const char *cmd, int nargs, ...)
   va_start(args, nargs);
 
   memcpy(printer_cmd + bufpos, cmd, 2);
-  STP_DEBUG(printf("Remote command: %s", cmd));
+  STP_DEBUG(printf("***Remote command: %s", cmd));
   bufpos += 2;
   printer_cmd[bufpos] = nargs % 256;
   printer_cmd[bufpos + 1] = (nargs >> 8) % 256;
@@ -660,13 +676,14 @@ do_remote_cmd_only(const char *cmd, int nargs, ...)
       }
   STP_DEBUG(printf("\n"));
   bufpos += 2 + nargs;
+  va_end(args);
 }
 
 static void
 add_resets(int count)
 {
   int i;
-  STP_DEBUG(printf("Add %d resets\n", count));
+  STP_DEBUG(printf("***Add %d resets\n", count));
   for (i = 0; i < count; i++)
     {
       printer_cmd[bufpos++] = '\033';
@@ -674,7 +691,7 @@ add_resets(int count)
     }
 }
 
-static int
+static void
 send_nulls(int fd)
 {
   char buf[16384];
@@ -685,37 +702,36 @@ send_nulls(int fd)
 static int
 init_packet(int fd, int force)
 {
-  int status;
   int tries = 0;
-  STP_DEBUG(printf("Init packet mode %d\n", force));
+  STP_DEBUG(printf("***Init packet mode %d\n", force));
 
  Loop:
   if (!force)
     {
-      STP_DEBUG(printf("Flushing early data...\n"));
+      STP_DEBUG(printf("***Flushing early data...\n"));
       flushData(fd, (unsigned char) -1);
     }
 
-  STP_DEBUG(printf("EnterIEEE...\n"));
+  STP_DEBUG(printf("***EnterIEEE...\n"));
   if (!EnterIEEE(fd))
     {
-      STP_DEBUG(printf("EnterIEEE failed!\n"));
+      STP_DEBUG(printf("***EnterIEEE failed!\n"));
       if (tries++ < 5)
 	{
-	  STP_DEBUG(printf("Retrying\n"));
+	  STP_DEBUG(printf("***Retrying\n"));
 	  send_nulls(fd);
 	  flushData(fd, (unsigned char) -1);
 	  goto Loop;
 	}
       return 1;
     }
-  STP_DEBUG(printf("Init...\n"));
+  STP_DEBUG(printf("***Init...\n"));
   if (!Init(fd))
     {
-      STP_DEBUG(printf("Init failed!\n"));
+      STP_DEBUG(printf("***Init failed!\n"));
       if (tries++ < 5)
 	{
-	  STP_DEBUG(printf("Retrying\n"));
+	  STP_DEBUG(printf("***Retrying\n"));
 	  send_nulls(fd);
 	  flushData(fd, (unsigned char) -1);
 	  goto Loop;
@@ -723,28 +739,27 @@ init_packet(int fd, int force)
       return 1;
     }
 
-  STP_DEBUG(printf("GetSocket...\n"));
+  STP_DEBUG(printf("***GetSocket...\n"));
   socket_id = GetSocketID(fd, "EPSON-CTRL");
   if (!socket_id)
     {
-      STP_DEBUG(printf("GetSocket failed!\n"));
+      STP_DEBUG(printf("***GetSocket failed!\n"));
       return 1;
     }
-  STP_DEBUG(printf("OpenChannel...\n"));
+  STP_DEBUG(printf("***OpenChannel...\n"));
   switch ( OpenChannel(fd, socket_id, &send_size, &receive_size) )
     {
     case -1:
-      STP_DEBUG(printf("Fatal Error return 1\n"));
+      STP_DEBUG(printf("***Fatal Error return 1\n"));
       return 1; /* unrecoverable error */
       break;
     case  0:
-      STP_DEBUG(printf("Error\n")); /* recoverable error ? */
+      STP_DEBUG(printf("***Error\n")); /* recoverable error ? */
       return 1;
       break;
     }
 
-  status = 1;
-  STP_DEBUG(printf("Flushing data...\n"));
+  STP_DEBUG(printf("***Flushing data...\n"));
   flushData(fd, socket_id);
   return 0;
 }
@@ -813,7 +828,7 @@ set_printer_model(void)
 	      if (desc.p_type == STP_PARAMETER_TYPE_BOOLEAN)
 		interchangeable_inks = desc.deflt.boolean;
 	      stp_parameter_description_destroy(&desc);
-	      STP_DEBUG(printf("Found it! %s\n", printer_model));
+	      STP_DEBUG(printf("***Found it! %s\n", printer_model));
 	      return;
 	    }
 	}
@@ -843,6 +858,12 @@ test_for_ii(const unsigned char *buf)
 	   strncmp("@BDC PS", (const char *)buf, 7));
 }
 
+static int
+test_for_ri(const unsigned char *buf)
+{
+  return !(strncmp("ri:00:OK;", (const char *)buf, 9));
+}
+
 static const stp_printer_t *
 initialize_printer(int quiet, int fail_if_not_found)
 {
@@ -870,14 +891,14 @@ initialize_printer(int quiet, int fail_if_not_found)
 	  status = SafeWrite(fd, init_str, sizeof(init_str) - 1);
 	  alarm(0);
 	  signal(SIGALRM, SIG_DFL);
-	  STP_DEBUG(printf("status %d alarm %d\n", status, alarm_interrupt));
+	  STP_DEBUG(printf("***status %d alarm %d\n", status, alarm_interrupt));
 	  if (status != sizeof(init_str) - 1 && (status != -1 || !alarm_interrupt))
 	    {
 	      fprintf(stderr, _("Cannot write to %s: %s\n"), raw_device,
 		      strerror(errno));
 	      exit(1);
 	    }
-	  STP_DEBUG(printf("Try old command %d alarm %d\n",
+	  STP_DEBUG(printf("***Try old command %d alarm %d\n",
 			    tries, alarm_interrupt));
 	  status = read_from_printer(fd, (char*)buf, 1024, 1);
 	  if (status <= 0 && tries > 0)
@@ -888,7 +909,7 @@ initialize_printer(int quiet, int fail_if_not_found)
 	  if (!forced_packet_mode &&
 	      status > 0 && !strstr((char *) buf, "@EJL ID") && tries < 3)
 	    {
-	      STP_DEBUG(printf("Found bad data: %s\n", buf));
+	      STP_DEBUG(printf("***Found bad data: %s\n", buf));
 	      /*
 	       * We know the printer's not dead.  Try to turn off status
 	       * and try again.
@@ -914,7 +935,7 @@ initialize_printer(int quiet, int fail_if_not_found)
 	  (void) SafeWrite(fd, printer_cmd, bufpos);
 	  flushData(fd, (unsigned char) -1);
 	  forced_packet_mode = !init_packet(fd, 1);
-	  STP_DEBUG(printf("Printer in packet mode....\n"));
+	  STP_DEBUG(printf("***Printer in packet mode....\n"));
 	  packet_initialized = 1;
 	  isnew = 1;
 	  /* request status command */
@@ -930,24 +951,38 @@ initialize_printer(int quiet, int fail_if_not_found)
 	      return NULL;
 	    }
 	}
-      STP_DEBUG(printf("status: %i\n", status));
-      STP_DEBUG(printf("Buf: %s\n", buf));
+      STP_DEBUG(printf("***status: %i\n", status));
+      STP_DEBUG(printf("***Buf: %s\n", buf));
       if (status > 0)
 	{
+	  char *xpos;
 	  pos = strstr((char*)buf, "@EJL ID");
-	  STP_DEBUG(printf("pos: %s\n", pos ? pos : "(null)"));
-	  if (pos)
-	    pos = strchr(pos, (int) ';');
-	  STP_DEBUG(printf("pos: %s\n", pos ? pos : "(null)"));
-	  if (pos)
-	    pos = strchr(pos + 1, (int) ';');
-	  STP_DEBUG(printf("pos: %s\n", pos ? pos : "(null)"));
-	  if (pos)
-	    pos = strchr(pos, (int) ':');
-	  STP_DEBUG(printf("pos: %s\n", pos ? pos : "(null)"));
+	  STP_DEBUG(printf("***pos: %s\n", pos ? pos : "(null)"));
 	  if (pos)
 	    {
-	      spos = strchr(pos, (int) ';');
+	      if (((xpos = strstr((char *)pos, "MDL:")) != NULL) ||
+		  ((xpos = strstr((char *)pos, "DES:")) != NULL))
+		{
+		  STP_DEBUG(printf("***xpos: %s\n", xpos ? xpos : "(null)"));
+		  pos = xpos + 4;
+		  STP_DEBUG(printf("***pos: %s\n", pos ? pos : "(null)"));
+		}
+	      else
+		{
+		  if (pos)
+		    pos = strchr(pos, (int) ';');
+		  STP_DEBUG(printf("***pos: %s\n", pos ? pos : "(null)"));
+		  if (pos)
+		    pos = strchr(pos + 1, (int) ';');
+		  STP_DEBUG(printf("***pos: %s\n", pos ? pos : "(null)"));
+		  if (pos)
+		    pos = strchr(pos, (int) ':');
+		  STP_DEBUG(printf("***pos: %s\n", pos ? pos : "(null)"));
+		  if (pos)
+		    pos++;
+		}
+	      if (pos)
+		spos = strchr(pos, (int) ';');
 	    }
 	  if (!pos)
 	    {
@@ -972,12 +1007,12 @@ initialize_printer(int quiet, int fail_if_not_found)
 		   * However, make it clear that this is a dummy,
 		   * so we don't actually try to print it out.
 		   */
-		  STP_DEBUG(printf("Can't find printer name, assuming Stylus Photo\n"));
+		  STP_DEBUG(printf("***Can't find printer name, assuming Stylus Photo\n"));
 		  printer_model = c_strdup("escp2-photo");
 		}
 	      else
 		{
-		  STP_DEBUG(printf("Can't get response to @EJL ID\n"));
+		  STP_DEBUG(printf("***Can't get response to @EJL ID\n"));
 		  close(fd);
 		  return NULL;
 		}
@@ -986,8 +1021,8 @@ initialize_printer(int quiet, int fail_if_not_found)
 	    {
 	      if (spos)
 		*spos = '\000';
-	      printer_model = pos + 1;
-	      STP_DEBUG(printf("printer model: %s\n", printer_model));
+	      printer_model = pos;
+	      STP_DEBUG(printf("***printer model: %s\n", printer_model));
 	    }
 	}
     }
@@ -1000,7 +1035,7 @@ initialize_printer(int quiet, int fail_if_not_found)
     }
 
   close(fd);
-  STP_DEBUG(printf("new? %s\n", isnew ? "yes" : "no"));
+  STP_DEBUG(printf("***new? %s\n", isnew ? "yes" : "no"));
   return the_printer_t;
 }
 
@@ -1013,7 +1048,7 @@ get_printer(int quiet, int fail_if_not_found)
     {
       const stp_printer_t *printer =
 	initialize_printer(quiet, fail_if_not_found);
-      STP_DEBUG(printf("init done, printer found? %s...\n",
+      STP_DEBUG(printf("***init done, printer found? %s...\n",
 			printer ? "yes" : "no"));
       return printer;
     }
@@ -1303,7 +1338,7 @@ do_old_status(status_cmd_t cmd, const char *buf, const stp_printer_t *printer)
 	      if (desc.p_type == STP_PARAMETER_TYPE_STRING_LIST)
 		{
 		  color_list = stp_string_list_create_copy(desc.bounds.str);
-		  STP_DEBUG(printf("Using color list from driver (%ld %ld)\n",
+		  STP_DEBUG(printf("***Using color list from driver (%ld %ld)\n",
 				   (long)stp_string_list_count(desc.bounds.str),
 				   (long)stp_string_list_count(color_list)));
 		  stp_parameter_description_destroy(&desc);
@@ -1317,8 +1352,8 @@ do_old_status(status_cmd_t cmd, const char *buf, const stp_printer_t *printer)
 	      stp_string_list_add_string(color_list, "Yellow", _("Yellow"));
 	      stp_string_list_add_string(color_list, "LightCyan", _("Light Cyan"));
 	      stp_string_list_add_string(color_list, "LightMagenta", _("Light Magenta"));
-	    }	  
-	  
+	    }
+
 	  if (cmd == CMD_STATUS)
 	    printf(_("Ink Levels:\n"));
 	  printf("%20s    %20s\n", _("Ink color"), _("Percent remaining"));
@@ -1327,9 +1362,9 @@ do_old_status(status_cmd_t cmd, const char *buf, const stp_printer_t *printer)
 	  if (cmd == CMD_STATUS)
 	    printf("\n");
 	}
-      STP_DEBUG(printf("looking at %s\n", buf));
+      STP_DEBUG(printf("***looking at %s\n", buf));
     } while ((buf = find_group(buf)) != NULL);
-}  
+}
 
 static void
 do_new_status(status_cmd_t cmd, char *buf, int bytes,
@@ -1340,11 +1375,16 @@ do_new_status(status_cmd_t cmd, char *buf, int bytes,
   const char *ind;
   const stp_string_list_t *color_list = NULL;
   stp_parameter_t desc;
-  const stp_vars_t *printvars = stp_printer_get_defaults(printer);
-  stp_describe_parameter(printvars, "ChannelNames", &desc);
-  if (desc.p_type == STP_PARAMETER_TYPE_STRING_LIST)
-    color_list = desc.bounds.str;
-  STP_DEBUG(printf("New format bytes: %d bytes\n", bytes));
+
+  const stp_vars_t *printvars = NULL;
+  if (printer)
+    {
+      printvars = stp_printer_get_defaults(printer);
+      stp_describe_parameter(printvars, "ChannelNames", &desc);
+      if (desc.p_type == STP_PARAMETER_TYPE_STRING_LIST)
+        color_list = desc.bounds.str;
+    }
+  STP_DEBUG(printf("***New format bytes: %d bytes\n", bytes));
   if (cmd == CMD_STATUS)
     printf(_("Printer Name: %s\n"),
 	    printer ? stp_printer_get_long_name(printer) : _("Unknown"));
@@ -1353,7 +1393,7 @@ do_new_status(status_cmd_t cmd, char *buf, int bytes,
       unsigned hdr = buf[i];
       unsigned total_param_count = buf[i + 1];
       unsigned param = buf[i + 2];
-      STP_DEBUG(printf("Header: %x param count: %d\n", hdr, total_param_count));
+      STP_DEBUG(printf("***Header: %x param count: %d\n", hdr, total_param_count));
       if (hdr == 0x0f)	/* Always report ink */
 	{
 	  size_t count = (total_param_count - 1) / param;
@@ -1363,26 +1403,26 @@ do_new_status(status_cmd_t cmd, char *buf, int bytes,
 	  printf("%20s    %20s\n", _("Ink color"), _("Percent remaining"));
 	  for (j = 0; j < count; j++)
 	    {
-	      STP_DEBUG(printf("    Ink %d: ind[0] %d ind[1] %d ind[2] %d interchangeable %d param %d count %d aux %d\n",
+	      STP_DEBUG(printf("***    Ink %d: ind[0] %d ind[1] %d ind[2] %d interchangeable %d param %d count %d aux %d\n",
 				j, ind[0], ind[1], ind[2], interchangeable_inks,
 				param, color_count, aux_color_count));
 	      if (ind[0] < color_count && param == 3 /* &&
 		  (interchangeable_inks || ind[1] >= aux_color_count ||
 		   ! aux_colors[(int) ind[1]]) */)
 		{
-		  STP_DEBUG(printf("Case 0\n"));
+		  STP_DEBUG(printf("***Case 0\n"));
 		  printf("%20s    %20d\n",
 			 gettext(colors_new[(int) ind[0]]), ind[2]);
 		}
 	      else if (ind[1] < aux_color_count && aux_colors[(int) ind[1]])
 		{
-		  STP_DEBUG(printf("Case 1\n"));
+		  STP_DEBUG(printf("***Case 1\n"));
 		  printf("%20s    %20d\n",
 			 gettext(aux_colors[(int) ind[1]]), ind[2]);
 		}
 	      else
 		{
-		  STP_DEBUG(printf("Case 2\n"));
+		  STP_DEBUG(printf("***Case 2\n"));
 		  printf("%8s 0x%02x 0x%02x    %20d\n",
 			 _("Unknown"), (unsigned char) ind[0],
 			 (unsigned char) ind[1], ind[2]);
@@ -1404,7 +1444,7 @@ do_new_status(status_cmd_t cmd, char *buf, int bytes,
 	      break;
 	    case 0x3:	/* Self-printing */
 	      print_self_printing_state(param);
-	      break; 
+	      break;
 	    case 0x4:	/* Warning */
 	      for (j = 0; j < total_param_count; j++)
 		{
@@ -1428,7 +1468,8 @@ do_new_status(status_cmd_t cmd, char *buf, int bytes,
 	}
       i += total_param_count + 2;
     }
-  stp_parameter_description_destroy(&desc);
+  if (printer)
+    stp_parameter_description_destroy(&desc);
   exit(0);
 }
 
@@ -1457,10 +1498,10 @@ do_status_command_internal(status_cmd_t cmd)
       exit(1);
     }
 
-  STP_DEBUG(printf("%s...\n", cmd_name));
+  STP_DEBUG(printf("***%s...\n", cmd_name));
   printer = get_printer(1, 0);
   if (!found_unknown_old_printer)
-    STP_DEBUG(printf("%s found %s%s\n", gettext(cmd_name),
+    STP_DEBUG(printf("***%s found %s%s\n", gettext(cmd_name),
 		      printer ? stp_printer_get_long_name(printer) :
 		      printer_model ? printer_model : "(null)",
 		      printer ? "" : "(Unknown model)"));
@@ -1521,10 +1562,94 @@ do_ink_level(void)
   do_status_command_internal(CMD_INK_LEVEL);
 }
 
-void
-do_extended_ink_info(int extended_output)
+static stp_string_list_t *
+get_ink_channel_list(const stp_printer_t *printer, int fd)
+{
+  stp_parameter_t desc;
+  char buf[1024];
+  int i;
+  char *ind;
+  stp_string_list_t *color_list = stp_string_list_create();
+
+  if (printer)
+    {
+      const stp_vars_t *printvars = stp_printer_get_defaults(printer);
+      stp_describe_parameter(printvars, "ChannelNames", &desc);
+    }
+
+  if (printer && desc.p_type == STP_PARAMETER_TYPE_STRING_LIST)
+    {
+      STP_DEBUG(printf("***Using color list from driver (%ld %ld)\n",
+		       (long)stp_string_list_count(desc.bounds.str),
+		       (long)stp_string_list_count(color_list)));
+      color_list = stp_string_list_create_copy(desc.bounds.str);
+      stp_parameter_description_destroy(&desc);
+    }
+  else
+    {
+      /*
+       * If we're using the "new" ink status format and we don't know
+       * about the printer, take the colors from the ink status
+       * message rather than from the ink list.  This gives us a
+       * last chance to determine the inks
+       */
+      /* request status command */
+      int status =
+	writeAndReadData(fd, socket_id, (const unsigned char*)"st\1\0\1",
+			 5, 1, (unsigned char *) buf, 1023,
+			 &send_size, &receive_size, &test_for_st);
+      if (status <= 0)
+	{
+	  stp_parameter_description_destroy(&desc);
+	  fprintf(stderr, _("\nCannot write to %s: %s\n"),
+		  raw_device, strerror(errno));
+	  exit(1);
+	}
+      buf[status] = '\0';
+      if ( buf[7] == '2' )
+	{
+	  STP_DEBUG(printf("***New format ink!\n"));
+	  /* new binary format ! */
+	  i = 10;
+	  while (buf[i] != 0x0f && i < status)
+	    i += buf[i + 1] + 2;
+	  ind = buf + i;
+	  i = 3;
+	  while (i < ind[1])
+	    {
+	      if (ind[i] < color_count)
+		{
+		  STP_DEBUG(printf("***   Case 0: Ink %d %d (%s)\n",
+				   i, ind[i], colors_new[(int) ind[i]]));
+		  stp_string_list_add_string_unsafe(color_list,
+						    colors_new[(int) ind[i]],
+						    colors_new[(int) ind[i]]);
+		}
+	      else if (ind[i] == 0x40 && ind[i + 1] < aux_color_count)
+		{
+		  STP_DEBUG(printf("***   Case 1: Ink %d %d (%s)\n",
+				   i, ind[i+1], aux_colors[(int) ind[i+1]]));
+		  stp_string_list_add_string_unsafe(color_list,
+						    aux_colors[(int) ind[i + 1]],
+						    aux_colors[(int) ind[i + 1]]);
+		}
+	      else
+		{
+		  STP_DEBUG(printf("***   Case 2: Unknown\n"));
+		  stp_string_list_add_string_unsafe(color_list, "Unknown",
+						    "Unknown");
+		}
+	      i+=3;
+	    }
+	}
+      STP_DEBUG(printf("***Using color list from status message\n"));
+    }
+  return color_list;
+}
+
+static void
+do_extended_ink_info_1(const stp_printer_t *printer)
 {
-  int fd;
   int status;
   char buf[1024];
   unsigned val, id, id2, year, year2, month, month2;
@@ -1532,9 +1657,132 @@ do_extended_ink_info(int extended_output)
 
   char *ind;
   int i;
+  int fd = open_raw_device();
+
+  stp_string_list_t *color_list = get_ink_channel_list(printer, fd);
+
+  for (i = 0; i < stp_string_list_count(color_list); i++)
+    {
+      char req[] = "ii\2\0\1\1";
+      req[5] = i + 1;
+      status =
+	writeAndReadData(fd, socket_id, (const unsigned char*)req,
+			 6, 1, (unsigned char *) buf, 1023,
+			 &send_size, &receive_size, &test_for_ii);
+      if (status <= 0)
+	{
+	  stp_string_list_destroy(color_list);
+	  CloseChannel(fd, socket_id);
+	  exit(1);
+	}
+      ind = strchr(buf, 'I');
+      if (!ind)
+	{
+	  STP_DEBUG(printf("***Case 0: failure %i (%s)\n", i, buf));
+	  printf("Cannot identify cartridge in slot %d\n", i);
+	}
+      else if (sscanf(ind,
+		      "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;IQT:%x,%x,%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
+		      &iv[0], &year, &month, &id,
+		      &iv[1], &iv[2], &iv[3], &iv[4], &iv[5],
+		      &year2, &month2, &id2) == 12 ||
+	       sscanf(ind,
+		      "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;IQT:%x,%x,%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
+		      &iv[0], &year, &month, &id,
+		      &iv[1], &iv[2], &iv[3], &iv[4], &iv[5],
+		      &year2, &month2, &id2) == 12)
+	{
+	  int j;
+	  STP_DEBUG(printf("***Case 1: i %i iv %ud %ud %ud %ud %ud %ud year %ud %ud mo %ud %ud id %ud %ud\n",
+			   i, iv[0], iv[1], iv[2], iv[3], iv[4], iv[5],
+			   year, year2, month, month2, id, id2));
+	  printf("%20s    %20s   %12s   %7s\n",
+		 _("Ink cartridge"), _("Percent remaining"), _("Part number"),
+		 _("Date"));
+	  printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
+		 gettext(stp_string_list_param(color_list, 0)->text),
+		 iv[0], id, (year > 80 ? 19 : 20), year, month);
+	  for (j = 1; j < 6; j++)
+	    printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
+		   gettext(stp_string_list_param(color_list, j)->text),
+		   iv[j], id2, (year2 > 80 ? 19 : 20), year2, month2);
+	  break;
+	}
+      else if (sscanf(ind,
+		      "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;IQT:%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
+		      &iv[0], &year, &month, &id,
+		      &iv[1], &iv[2], &iv[3],
+		      &year2, &month2, &id2) == 10 ||
+	       sscanf(ind,
+		      "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;IQT:%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
+		      &iv[0], &year, &month, &id,
+		      &iv[1], &iv[2], &iv[3],
+		      &year2, &month2, &id2) == 10)
+	{
+	  int j;
+	  STP_DEBUG(printf("***Case 2: i %i iv %ud %ud %ud %ud year %ud %ud mo %ud %ud id %ud %ud\n",
+			   i, iv[0], iv[1], iv[2], iv[3],
+			   year, year2, month, month2, id, id2));
+	  printf("%20s    %20s   %12s   %7s\n",
+		 _("Ink cartridge"), _("Percent remaining"), _("Part number"),
+		 _("Date"));
+	  printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
+		 gettext(stp_string_list_param(color_list, 0)->text),
+		 iv[0], id, (year > 80 ? 19 : 20), year, month);
+	  for (j = 1; j < 4; j++)
+	    printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
+		   gettext(stp_string_list_param(color_list, j)->text),
+		   iv[j], id2, (year2 > 80 ? 19 : 20), year2, month2);
+	  break;
+	}
+      else if (sscanf(ind,
+		      "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
+		      &val, &year, &month, &id ) == 4 ||
+	       sscanf(ind,
+		      "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
+		      &val, &year, &month, &id ) == 4)
+	{
+	  STP_DEBUG(printf("***Case 3: i %i val %ud year %ud mo %ud id %ud\n",
+			   i, val, year, month, id));
+	  if (i == 0)
+	    printf("%20s    %20s   %12s   %7s\n",
+		   _("Ink cartridge"), _("Percent remaining"), _("Part number"),
+		   _("Date"));
+	  printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
+		 gettext(stp_string_list_param(color_list, i)->text),
+		 val, id, (year > 80 ? 19 : 20), year, month);
+	}
+      else if (sscanf(ind,
+		      "IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
+		      &val, &year, &month, &id ) == 4 ||
+	       sscanf(ind,
+		      "IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
+		      &val, &year, &month, &id ) == 4)
+	{
+	  STP_DEBUG(printf("***Case 4: i %i val %ud year %ud mo %ud id %ud\n",
+			   i, val, year, month, id));
+	  if (i == 0)
+	    printf("%20s    %20s   %12s   %7s\n",
+		   _("Ink cartridge"), _("Percent remaining"), _("Part number"),
+		   _("Date"));
+	  printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
+		 gettext(stp_string_list_param(color_list, i)->text),
+		 val, id, (year > 80 ? 19 : 20), year, month);
+	}
+      else
+	{
+	  STP_DEBUG(printf("***Case 5: failure %i (%s)\n", i, ind));
+	  printf("Cannot identify cartridge in slot %d\n", i);
+	}
+    }
+  stp_string_list_destroy(color_list);
+  CloseChannel(fd, socket_id);
+}
+
+void
+do_extended_ink_info(void)
+{
   const stp_printer_t *printer;
-  const stp_vars_t *printvars;
-  stp_parameter_t desc;
 
   if (!raw_device)
     {
@@ -1543,212 +1791,67 @@ do_extended_ink_info(int extended_output)
     }
 
   printer = get_printer(1, 0);
-  if (printer)
-    {
-      printvars = stp_printer_get_defaults(printer);
-      stp_describe_parameter(printvars, "ChannelNames", &desc);
-    }
-  else
+  if (!printer)
     fprintf(stderr,
 	    "Warning! Printer %s is not known; information may be incomplete or incorrect\n",
 	    printer_model ? printer_model : "(unknown printer)");
 
-  fd = open_raw_device();
-
   if (isnew)
-    {
-      stp_string_list_t *color_list = stp_string_list_create();
-
-      if (printer && desc.p_type == STP_PARAMETER_TYPE_STRING_LIST)
-	{
-	  STP_DEBUG(printf("Using color list from driver (%ld %ld)\n",
-			    (long)stp_string_list_count(desc.bounds.str),
-			    (long)stp_string_list_count(color_list)));
-	  color_list = stp_string_list_create_copy(desc.bounds.str);
-	  stp_parameter_description_destroy(&desc);
-	}
-      else
-	{
-	  /*
-	   * If we're using the "new" ink status format and we don't know
-	   * about the printer, take the colors from the ink status
-	   * message rather than from the ink list.  This gives us a
-	   * last chance to determine the inks
-	   */
-	  /* request status command */
-	  status =
-	    writeAndReadData(fd, socket_id, (const unsigned char*)"st\1\0\1",
-			     5, 1, (unsigned char *) buf, 1023,
-			     &send_size, &receive_size, &test_for_st);
-	  if (status <= 0)
-	    {
-	      stp_parameter_description_destroy(&desc);
-	      fprintf(stderr, _("\nCannot write to %s: %s\n"),
-		      raw_device, strerror(errno));
-	      exit(1);
-	    }
-	  buf[status] = '\0';
-	  if ( buf[7] == '2' )
-	    {
-	      STP_DEBUG(printf("New format ink!\n"));
-	      /* new binary format ! */
-	      i = 10;
-	      while (buf[i] != 0x0f && i < status)
-		i += buf[i + 1] + 2;
-	      ind = buf + i;
-	      i = 3;
-	      while (i < ind[1])
-		{
-		  if (ind[i] < color_count)
-		    {
-		      STP_DEBUG(printf("   Case 0: Ink %d %d (%s)\n",
-				       i, ind[i], colors_new[(int) ind[i]]));
-		      stp_string_list_add_string(color_list,
-						 colors_new[(int) ind[i]],
-						 colors_new[(int) ind[i]]);
-		    }
-		  else if (ind[i] == 0x40 && ind[i + 1] < aux_color_count)
-		    {
-		      STP_DEBUG(printf("   Case 1: Ink %d %d (%s)\n",
-				       i, ind[i+1], aux_colors[(int) ind[i+1]]));
-		      stp_string_list_add_string(color_list,
-						 aux_colors[(int) ind[i + 1]],
-						 aux_colors[(int) ind[i + 1]]);
-		    }
-		  else
-		    {
-		      STP_DEBUG(printf("   Case 2: Unknown\n"));
-		      stp_string_list_add_string(color_list, "Unknown",
-						 "Unknown");
-		    }
-		  i+=3;
-		}
-	    }
-	  STP_DEBUG(printf("Using color list from status message\n"));
-	}
-
-      for (i = 0; i < stp_string_list_count(color_list); i++)
-        {
-	  char req[] = "ii\2\0\1\1";
-	  req[5] = i + 1;
-	  status =
-	    writeAndReadData(fd, socket_id, (const unsigned char*)req,
-			     6, 1, (unsigned char *) buf, 1023,
-			     &send_size, &receive_size, &test_for_ii);
-	  if (status <= 0)
-	    {
-	      CloseChannel(fd, socket_id);
-	      exit(1);
-	    }
-	  ind = strchr(buf, 'I');
-	  if (!ind)
-	    {
-	      STP_DEBUG(printf("Case 0: failure %i (%s)\n", i, buf));
-	      printf("Cannot identify cartridge in slot %d\n", i);
-	    }
-	  else if (sscanf(ind,
-			  "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;IQT:%x,%x,%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
-			  &iv[0], &year, &month, &id,
-			  &iv[1], &iv[2], &iv[3], &iv[4], &iv[5],
-			  &year2, &month2, &id2) == 12 ||
-		   sscanf(ind,
-			  "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;IQT:%x,%x,%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
-			  &iv[0], &year, &month, &id,
-			  &iv[1], &iv[2], &iv[3], &iv[4], &iv[5],
-			  &year2, &month2, &id2) == 12)
-	    {
-	      int j;
-	      STP_DEBUG(printf("Case 1: i %i iv %ud %ud %ud %ud %ud %ud year %ud %ud mo %ud %ud id %ud %ud\n",
-				i, iv[0], iv[1], iv[2], iv[3], iv[4], iv[5],
-				year, year2, month, month2, id, id2));
-	      printf("%20s    %20s   %12s   %7s\n",
-		     _("Ink cartridge"), _("Percent remaining"), _("Part number"),
-		     _("Date"));
-	      printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
-		     gettext(stp_string_list_param(color_list, 0)->text),
-		     iv[0], id, (year > 80 ? 19 : 20), year, month);
-	      for (j = 1; j < 6; j++)
-		printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
-		       gettext(stp_string_list_param(color_list, j)->text),
-		       iv[j], id2, (year2 > 80 ? 19 : 20), year2, month2);
-	      break;
-	    }
-	  else if (sscanf(ind,
-			  "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;IQT:%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
-			  &iv[0], &year, &month, &id,
-			  &iv[1], &iv[2], &iv[3],
-			  &year2, &month2, &id2) == 10 ||
-		   sscanf(ind,
-			  "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;IQT:%x,%x,%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*xIK1:%*x;IK2;%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
-			  &iv[0], &year, &month, &id,
-			  &iv[1], &iv[2], &iv[3],
-			  &year2, &month2, &id2) == 10)
-	    {
-	      int j;
-	      STP_DEBUG(printf("Case 2: i %i iv %ud %ud %ud %ud year %ud %ud mo %ud %ud id %ud %ud\n",
-				i, iv[0], iv[1], iv[2], iv[3],
-				year, year2, month, month2, id, id2));
-	      printf("%20s    %20s   %12s   %7s\n",
-		     _("Ink cartridge"), _("Percent remaining"), _("Part number"),
-		     _("Date"));
-	      printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
-		     gettext(stp_string_list_param(color_list, 0)->text),
-		     iv[0], id, (year > 80 ? 19 : 20), year, month);
-	      for (j = 1; j < 4; j++)
-		printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
-		       gettext(stp_string_list_param(color_list, j)->text),
-		       iv[j], id2, (year2 > 80 ? 19 : 20), year2, month2);
-	      break;
-	    }
-	  else if (sscanf(ind,
-			  "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
-			  &val, &year, &month, &id ) == 4 ||
-		   sscanf(ind,
-			  "II:01;IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
-			  &val, &year, &month, &id ) == 4)
-	    {
-	      STP_DEBUG(printf("Case 3: i %i val %ud year %ud mo %ud id %ud\n",
-				i, val, year, month, id));
-	      if (i == 0)
-		printf("%20s    %20s   %12s   %7s\n",
-		       _("Ink cartridge"), _("Percent remaining"), _("Part number"),
-		       _("Date"));
-	      printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
-		     gettext(stp_string_list_param(color_list, i)->text),
-		     val, id, (year > 80 ? 19 : 20), year, month);
-	    }
-	  else if (sscanf(ind,
-			  "IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:EPSON;",
-			  &val, &year, &month, &id ) == 4 ||
-		   sscanf(ind,
-			  "IQT:%x;TSH:%*4s;PDY:%x;PDM:%x;IC1:%x;IC2:%*x;IK1:%*x;IK2:%*x;TOV:%*x;TVU:%*x;LOG:INKbyEPSON;",
-			  &val, &year, &month, &id ) == 4)
-	    {
-	      STP_DEBUG(printf("Case 4: i %i val %ud year %ud mo %ud id %ud\n",
-				i, val, year, month, id));
-	      if (i == 0)
-		printf("%20s    %20s   %12s   %7s\n",
-		       _("Ink cartridge"), _("Percent remaining"), _("Part number"),
-		       _("Date"));
-	      printf("%20s    %20d    T0%03d            %2d%02d-%02d\n",
-		     gettext(stp_string_list_param(color_list, i)->text),
-		     val, id, (year > 80 ? 19 : 20), year, month);
-	    }
-	  else
-	    {
-	      STP_DEBUG(printf("Case 5: failure %i (%s)\n", i, ind));
-	      printf("Cannot identify cartridge in slot %d\n", i);
-	    }
-	}
-      stp_string_list_destroy(color_list);
-      CloseChannel(fd, socket_id);
-    }
+    do_extended_ink_info_1(printer);
   else
+    do_ink_level();
+}
+
+void
+do_reset_ink_levels(void)
+{
+  const stp_printer_t *printer;
+  int fd;
+  int i;
+
+  stp_string_list_t *color_list;
+
+  if (!raw_device)
     {
-      (void) close(fd);
-      do_ink_level();
+      fprintf(stderr,_("Resetting ink levels requires using a raw device.\n"));
+      exit(1);
     }
-  exit(0);
+
+  printer = get_printer(1, 0);
+  if (!printer)
+    {
+      fprintf(stderr,
+	      "Error! Printer %s is not known; cannot reset ink\n",
+	      printer_model ? printer_model : "(unknown printer)");
+      exit(1);
+    }
+
+  if (!isnew)
+    {
+      fprintf(stderr, "Cannot reset ink for printer %s\n", printer_model);
+    }
+  fd = open_raw_device();
+  color_list = get_ink_channel_list(printer, fd);
+  for (i = 0; i < stp_string_list_count(color_list); i++)
+    {
+      int status;
+      char buf[1024];
+      char req[] = "ri\2\0\0\0";
+      req[5] = i;
+      STP_DEBUG(printf("***Attempt to reset ink for channel %d\n", i));
+      status =
+	writeAndReadData(fd, socket_id, (const unsigned char*)req,
+			 6, 1, (unsigned char *) buf, 1023,
+			 &send_size, &receive_size, &test_for_ri);
+      if (status <= 0)
+	{
+	  stp_string_list_destroy(color_list);
+	  CloseChannel(fd, socket_id);
+	  exit(1);
+	}
+    }
+  stp_string_list_destroy(color_list);
+  CloseChannel(fd, socket_id);
 }
 
 void
