@@ -1,5 +1,4 @@
 /*
- * "$Id: gutenprintui-internal.h,v 1.3 2005/09/17 21:54:33 rlk Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -34,8 +33,8 @@
 #endif
 
 #include <sys/types.h>
-#include <gtk/gtk.h>
 
+#include <gutenprintui2/gutenprintui.h>
 #include <gutenprint/gutenprint.h>
 
 typedef struct
@@ -75,17 +74,29 @@ typedef struct
   gboolean is_visible;
 } curve_option_t;
 
+typedef struct
+{
+  GtkWidget *f_label;
+  GtkWidget *f_entry;
+  GtkWidget *f_button;
+  GtkWidget *f_browser;
+  gboolean f_is_visible;
+} file_option_t;
+
 typedef struct
 {
   const stp_parameter_t *fast_desc;
   int is_active;
   int is_enabled;
+  int reset_all;
   GtkWidget *checkbox;
+  GtkWidget *reset_btn;
   union {
     list_option_t list;
     float_option_t flt;
     curve_option_t curve;
     boolean_option_t bool;
+    file_option_t file;
   } info;
 } option_t;
 
@@ -238,4 +249,32 @@ extern void stpui_create_scale_entry(option_t    *option,
 stp_image_t *stpui_image_thumbnail_new(const guchar *data, gint w, gint h,
 				       gint bpp);
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpointer-to-int-cast"
+static inline gint
+p2gint(void *p)
+{
+  return (gint) p;
+}
+#pragma GCC diagnostic pop
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wint-to-pointer-cast"
+static inline void *
+gint2p(int i)
+{
+  return (gpointer) i;
+}
+#pragma GCC diagnostic pop
+
+#pragma GCC diagnostic ignored "-Woverlength-strings"
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-qual"
+static inline void *
+cast_safe(const void *ptr)
+{
+  return (void *)ptr;
+}
+#pragma GCC diagnostic pop
+
 #endif  /* GUTENPRINTUI_INTERNAL_H */
