@@ -1,6 +1,4 @@
 /*
- * "$Id: dither-impl.h,v 1.25 2005/04/12 00:57:01 rlk Exp $"
- *
  *   Internal implementation of dither algorithms
  *
  *   Copyright 1997-2003 Michael Sweet (mike@easysw.com) and
@@ -57,7 +55,10 @@ extern "C" {
 #define D_HYBRID_EVENTONE (D_ORDERED_BASE | D_EVENTONE)
 #define D_HYBRID_UNITONE (D_ORDERED_BASE | D_UNITONE)
 #define D_HYBRID_EVENBETTER (D_ORDERED_BASE | D_EVENBETTER)
-#define D_PREDITHERED 128
+#define D_PREDITHERED 256
+#define D_ORDERED_NEW 512
+#define D_ORDERED_SEGMENTED 1024
+#define D_ORDERED_SEGMENTED_NEW (D_ORDERED_SEGMENTED | D_ORDERED_NEW)
 #define D_INVALID -2
 
 #define DITHER_FAST_STEPS (6)
@@ -148,7 +149,6 @@ typedef struct dither
   int x_aspect;			/* Aspect ratio numerator */
   int y_aspect;			/* Aspect ratio denominator */
 
-  double transition;		/* Exponential scaling for transition region */
 
   int *offset0_table;
   int *offset1_table;
@@ -163,7 +163,6 @@ typedef struct dither
 				 * some things */
 
   stp_dither_matrix_impl_t dither_matrix;
-  stp_dither_matrix_impl_t transition_matrix;
   stpi_dither_channel_t *channel;
   unsigned channel_count;
   unsigned total_channel_count;
@@ -258,6 +257,3 @@ do									\
 #endif
 
 #endif /* GUTENPRINT_INTERNAL_DITHER_IMPL_H */
-/*
- * End of "$Id: dither-impl.h,v 1.25 2005/04/12 00:57:01 rlk Exp $".
- */
