@@ -1,5 +1,4 @@
 /*
- * "$Id: escp2-channels.c,v 1.87 2008/10/29 00:10:42 easysw Exp $"
  *
  *   Print plug-in EPSON ESC/P2 driver for the GIMP.
  *
@@ -47,6 +46,12 @@ load_subchannel(stp_mxml_node_t *node, stp_mxml_node_t *root, physical_subchanne
   name = stp_mxmlElementGetAttr(node, "headOffset");
   if (name)
     icl->head_offset = stp_xmlstrtol(name);
+  name = stp_mxmlElementGetAttr(node, "name");
+  if (name)
+    icl->name = stp_strdup(name);
+  name = stp_mxmlElementGetAttr(node, "text");
+  if (name)
+    icl->text = stp_strdup(name);
   while (child)
     {
       if (child->type == STP_MXML_ELEMENT)
@@ -126,21 +131,13 @@ load_channel(stp_mxml_node_t *node, stp_mxml_node_t *root, ink_channel_t *icl)
 		{
 		  cchild = stp_mxmlFindElement(root, root, "curve", "name",
 					       cref, STP_MXML_DESCEND);
-		  if (!cchild)
-		    {
-		      stp_erprintf("Cannot find curve named '%s'!\n", cref);
-		      stp_abort();
-		    }
+		  STPI_ASSERT(cchild, NULL);
 		}
 	      else
 		{
 		  while (cchild && cchild->type != STP_MXML_ELEMENT)
 		    cchild = cchild->next;
-		  if (!cchild)
-		    {
-		      stp_erprintf("Cannot find curve!\n");
-		      stp_abort();
-		    }
+		  STPI_ASSERT(cchild, NULL);
 		}
 	      curve = stp_curve_create_from_xmltree(cchild);
 	      icl->hue_curve = curve;
@@ -157,7 +154,8 @@ load_channel(stp_mxml_node_t *node, stp_mxml_node_t *root, ink_channel_t *icl)
 }
 
 static void
-load_inkname(stp_mxml_node_t *node, stp_mxml_node_t *root, inkname_t *inl)
+load_inkname(stp_mxml_node_t *node, stp_mxml_node_t *root, inkname_t *inl,
+	     inklist_t *ikl)
 {
   const char *name;
   stp_mxml_node_t *child = node->child;
@@ -234,6 +232,8 @@ load_inkname(stp_mxml_node_t *node, stp_mxml_node_t *root, inkname_t *inl)
 	inl->inkset = INKSET_CcMmYKk;
       else if (!strcmp(name, "Quadtone"))
 	inl->inkset = INKSET_QUADTONE;
+      else if (!strcmp(name, "Hextone"))
+	inl->inkset = INKSET_HEXTONE;
       else if (!strcmp(name, "OTHER"))
 	inl->inkset = INKSET_OTHER;
       else if (!strcmp(name, "Extended"))
@@ -283,6 +283,12 @@ load_inkname(stp_mxml_node_t *node, stp_mxml_node_t *root, inkname_t *inl)
 		  cchild = cchild->next;
 		}
 	    }
+	  else if (!strcmp(child->value.element.name, "initSequence") &&
+		   child->child && child->child->type == STP_MXML_TEXT)
+	    ikl->init_sequence = stp_xmlstrtoraw(child->child->value.text.string);
+	  else if (!strcmp(child->value.element.name, "deinitSequence") &&
+		   child->child && child->child->type == STP_MXML_TEXT)
+	    ikl->deinit_sequence = stp_xmlstrtoraw(child->child->value.text.string);
 	}
       child = child->next;
     }
@@ -349,9 +355,17 @@ load_inklist(stp_mxml_node_t *node, stp_mxml_node_t *root, inklist_t *ikl)
 
   while (child)
     {
-      if (child->type == STP_MXML_ELEMENT &&
-	  !strcmp(child->value.element.name, "InkName"))
-	count++;
+      if (child->type == STP_MXML_ELEMENT)
+	{
+	  if (!strcmp(child->value.element.name, "InkName"))
+	    count++;
+	  else if (!strcmp(child->value.element.name, "initSequence") &&
+		   child->child && child->child->type == STP_MXML_TEXT)
+	    ikl->init_sequence = stp_xmlstrtoraw(child->child->value.text.string);
+	  else if (!strcmp(child->value.element.name, "deinitSequence") &&
+		   child->child && child->child->type == STP_MXML_TEXT)
+	    ikl->deinit_sequence = stp_xmlstrtoraw(child->child->value.text.string);
+	}
       child = child->next;
     }
   name = stp_mxmlElementGetAttr(node, "name");
@@ -369,7 +383,12 @@ load_inklist(stp_mxml_node_t *node, stp_mxml_node_t *root, inklist_t *ikl)
       if (child->type == STP_MXML_ELEMENT)
 	{
 	  if (!strcmp(child->value.element.name, "InkName"))
-	    load_inkname(child, root, &(ikl->inknames[count++]));
+	    {
+	      inkname_t *inl = &(ikl->inknames[count++]);
+	      inl->init_sequence = ikl->init_sequence;
+	      inl->deinit_sequence = ikl->deinit_sequence;
+	      load_inkname(child, root, inl, ikl);
+	    }
 	  else if (!strcmp(child->value.element.name, "Shades"))
 	    load_shades(child, root, ikl);
 	}
@@ -395,7 +414,7 @@ load_inkgroup(const char *name)
 	{
 	  int count = 0;
 	  stp_mxml_node_t *node = stp_mxmlFindElement(inkgroup, inkgroup,
-						      "escp2:InkGroup", NULL,
+						      "escp2InkGroup", NULL,
 						      NULL, STP_MXML_DESCEND);
 	  if (node)
 	    {
@@ -438,13 +457,8 @@ stp_escp2_load_inkgroup(const stp_vars_t *v, const char *name)
 {
   stpi_escp2_printer_t *printdef = stp_escp2_get_printer(v);
   inkgroup_t *igl = load_inkgroup(name);
-  if (igl)
-    printdef->inkgroup = igl;
-  else
-    {
-      stp_erprintf("Unable to load ink definitions from %s!\n", name);
-      stp_abort();
-    }
+  STPI_ASSERT(igl, v);
+  printdef->inkgroup = igl;
   return (igl != NULL);
 }
 
@@ -454,14 +468,9 @@ stpi_escp2_get_default_black_inkset(void)
   if (! default_black_inkgroup)
     {
       default_black_inkgroup = load_inkgroup("escp2/inks/defaultblack.xml");
-      if (! default_black_inkgroup ||
-	  default_black_inkgroup->n_inklists < 1 ||
-	  default_black_inkgroup->inklists[0].n_inks < 1)
-	{
-	  stp_erprintf("Default black inkgroup: %lx\n", (long) default_black_inkgroup);
-	  stp_erprintf("Unable to load default black ink definition!\n");
-	  stp_abort();
-	}
+      STPI_ASSERT(default_black_inkgroup &&
+		  default_black_inkgroup->n_inklists >= 1 &&
+		  default_black_inkgroup->inklists[0].n_inks >= 1, NULL);
     }
   return &(default_black_inkgroup->inklists[0].inknames[0]);
 }
