@@ -1,5 +1,4 @@
 /*
- * "$Id: printers.c,v 1.94 2015/07/13 02:18:20 speachy Exp $"
  *
  *   Print plug-in driver utility functions for the GIMP.
  *
@@ -66,7 +65,6 @@ struct stp_printer
   char       *family;           /* Printer family */
   char	     *manufacturer;	/* Printer manufacturer */
   char	     *device_id; 	/* IEEE 1284 device ID */
-  char       *foomatic_id;	/* Foomatic printer ID */
   char       *comment;	     	/* Comment string, if any */
   int        model;             /* Model number */
   int	     vars_initialized;
@@ -136,11 +134,6 @@ stpi_printer_freefunc(void *item)
       stp_free(printer->comment);
       printer->comment = NULL;
     }
-  if (printer->foomatic_id)
-    {
-      stp_free(printer->foomatic_id);
-      printer->comment = NULL;
-    }
   stp_free(printer->long_name);
   stp_free(printer->family);
   stp_free(printer);
@@ -206,7 +199,8 @@ stp_printer_get_manufacturer(const stp_printer_t *printer)
 const char *
 stp_printer_get_foomatic_id(const stp_printer_t *printer)
 {
-  return printer->foomatic_id;
+  stp_erprintf("stp_printer_get_foomatic_id is DEPRECATED\n");
+  return NULL;
 }
 
 const char *
@@ -287,24 +281,7 @@ stp_get_printer_by_device_id(const char *device_id)
 const stp_printer_t *
 stp_get_printer_by_foomatic_id(const char *foomatic_id)
 {
-  stp_list_item_t *printer_item;
-  if (printer_list == NULL)
-    {
-      stp_erprintf("No printer drivers found: "
-		   "are STP_DATA_PATH and STP_MODULE_PATH correct?\n");
-      stpi_init_printer_list();
-    }
-  if (! foomatic_id || strcmp(foomatic_id, "") == 0)
-    return NULL;
-
-  printer_item = stp_list_get_start(printer_list);
-  while (printer_item)
-    {
-      if (strcmp(((const stp_printer_t *) stp_list_item_get_data(printer_item))->foomatic_id,
-		 foomatic_id) == 0)
-	return ((const stp_printer_t *) stp_list_item_get_data(printer_item));
-      printer_item = stp_list_item_next(printer_item);
-    }
+  stp_erprintf("stp_get_printer_by_foomatic_id is DEPRECATED\n");
   return NULL;
 }
 
@@ -1127,9 +1104,6 @@ stp_printer_create_from_xmltree(stp_mxml_node_t *printer, /* The printer node */
   stmp = stp_mxmlElementGetAttr(printer, "deviceid");
   if (stmp)
     outprinter->device_id = stp_strdup(stmp);
-  stmp = stp_mxmlElementGetAttr(printer, "foomaticid");
-  if (stmp)
-    outprinter->foomatic_id = stp_strdup(stmp);
 
   child = printer->child;
   while (child)
