@@ -417,7 +417,7 @@ expand_line (unsigned char *src, unsigned char *dst, int height, int skip,
   /*
    * src is a pointer to a bit stream which is composed of fields of height
    * bpp starting with the most significant bit of the first byte and
-   * proceding from there with no regard to byte boundaries.  For the
+   * proceeding from there with no regard to byte boundaries.  For the
    * existing Epson printers, bpp is 1 or 2, which means fields will never
    * cross byte boundaries.  However, if bpp were 3, this would undoubtedly
    * happen.  This routine will make no assumptions about bpp, and handle each
@@ -1715,7 +1715,7 @@ main(int argc,char *argv[])
 	    {
 	      if (!(fp_w = fopen(argv[arg],"w")))
 		{
-		  perror("Error opening ouput file");
+		  perror("Error opening output file");
 		  exit(-1);
 		}
 	    }
